@@ -17,18 +17,17 @@ group :maintenance, optional: true do
 	gem "utopia-project"
 end
 
-group :test do
+group "test" do
 	gem "sus"
 	gem "covered"
 	gem "decode"
 	
 	gem "rubocop"
-	gem "rubocop-md"
 	gem "rubocop-socketry"
 	
+	gem "traces"
+	gem "metrics"
+	
 	gem "bake-test"
 	gem "bake-test-external"
-	
-	gem "stringio"
-	gem "traces"
 end
